@@ -2,6 +2,7 @@ from tg import expose, flash, require, url, request, redirect, tmpl_context, val
 from pylons.i18n import ugettext as _, lazy_ugettext as l_
 from pylons.controllers.util import abort
 from repoze.what import predicates
+import codecs
 
 from libacr import acr_zones, forms
 from libacr.lib import url, current_user_id, language, user_can_create_children_in_page, \
@@ -89,6 +90,10 @@ class PagesAdminController(BaseAdminController):
         for attribute in kw.get('attributes', []):
             name = attribute['name']
             value = attribute['value']
+
+            if isinstance(value, unicode):
+                value = value.encode('ascii', 'xmlcharrefreplace')
+
             DBSession.add(Attribute(name=name, value=value, page=page))
 
 
