@@ -10,7 +10,6 @@ from libacr.model.content import Tag, Page, Slice, Content, ContentData, View
 
 from tw.api import WidgetsList
 import tw.forms as widgets
-from tw.tinymce import TinyMCE, MarkupConverter
 from formencode import validators
 from libacr.views.manager import ViewsManager
 from libacr.forms import order_values
@@ -41,7 +40,15 @@ class ViewsAdminController(BaseAdminController):
                 viewfields = fields.code
             else:
                 viewfields = ''
-            values = dict(uid=view.uid, code=view.code, name=view.name, viewfields=viewfields)
+
+            preview_declaration_name = '%s_preview' % view.name
+            preview = DBSession.query(View).filter_by(name=preview_declaration_name).first()
+            if preview:
+                preview = preview.code
+            else:
+                preview = ''
+
+            values = dict(uid=view.uid, code=view.code, name=view.name, viewfields=viewfields, preview=preview)
         else:
             values = dict()
 
