@@ -1,6 +1,8 @@
 from repoze.what import predicates
 
-from tw.forms import SingleSelectField, TextArea
+from tw.api import WidgetsList
+from tw.forms import SingleSelectField, TextArea, TextField, FieldSet
+from tw.dynforms import GrowingRepeater, GrowingTableFieldSet
 from sprox.formbase import EditableForm, AddRecordForm
 from sprox.widgets import PropertyMultipleSelectField
 
@@ -17,28 +19,39 @@ order_values = [0]
 order_values.extend(xrange(-10, 0))
 order_values.extend(xrange(1, 11))
 
+class AttributesFieldSet(GrowingTableFieldSet):
+    children = [
+        TextField('name', label_text = "Name", attrs=dict(style="width:75px")),
+        TextField('value', label_text = "Value", attrs=dict(style="width:115px"))
+    ] 
+
 class EditSliceForm(EditableForm):
     __model__ = Slice
+    __base_widget_args__ = {'attrs':{"onsubmit": "twd_blank_deleted()"}}
     __omit_fields__ = ['view_uid', 'content_uid', 'page_uid', 'view', 'slice_order', 'content']
     __hide_fields__ = ['uid']
-    __field_order__ = ['uid']
+    __field_order__ = ['uid', 'name', 'page', 'zone', 'tags', 'attributes']
     __dropdown_field_names__ = {'page' : 'title'}
     zone = SingleSelectField('zone', options=zip(acr_zones, acr_zones))
+    attributes = AttributesFieldSet('attributes')
 
 class CloneSliceForm(EditableForm):
     __model__ = Slice
-    __omit_fields__ = ['view_uid', 'content_uid', 'page_uid', 'view', 'slice_order', 'content', 'zone', 'name', 'tags']
+    __omit_fields__ = ['view_uid', 'content_uid', 'page_uid', 'view', 'slice_order', 
+                       'content', 'zone', 'name', 'tags', 'attributes']
     __hide_fields__ = ['uid']
     __field_order__ = ['uid']
     __dropdown_field_names__ = {'page' : 'title'}
 
 class EditPageForm(EditableForm):
     __model__ = Page
+    __base_widget_args__ = {'attrs':{"onsubmit": "twd_blank_deleted()"}}
     __omit_fields__ = ['children', 'parent_uid', 'slices']
     __hide_fields__ = ['uid']
     __dropdown_field_names__ = {'page' : 'title'}
     __field_order__ = ['uid', 'parent', 'uri', 'title']
     __require_fields__ = ['uri', 'title']
+    attributes = AttributesFieldSet('attributes')
 
 class EditContentForm(EditableForm):
     __model__ = Content
