@@ -85,7 +85,7 @@ def render_slice(page, slice):
                         <div class="acr_edit_button">
                           <div style="float:left;">
                             <a href="#"
-                               onclick="jQuery(this).parents('.acr_edit_container').hide(); return false;">
+                               onclick="jQuery(this).parents('.acr_edit_container').hide(); event.stopPropagation(); return false;">
                                 hide
                             </a>
                             &nbsp;
@@ -101,33 +101,53 @@ def render_slice(page, slice):
                         </div>
                       </div>'''  % ( acr_url('/admin/slices/edit',uid=slice.uid) )
 
-    renderer = view_manager.find_view(slice.view)
-    if renderer:
-        try:
-            result += renderer.render(page, slice, slice.content.data)
-        except Exception, e:
-            tb = traceback.extract_tb(sys.exc_info()[2])
-            log.warning(''.join(traceback.format_list(tb)))
-            result += str(e)
+
+    if slice.getattr('force-preview'):
+        result += preview_slice(page, slice)
     else:
-        result += u'<div class="acr_wrong_view">Unsupported View Type</div>'
+        renderer = view_manager.find_view(slice.view)
+        if renderer:
+            try:
+                result += renderer.render(page, slice, slice.content.data)
+            except Exception, e:
+                tb = traceback.extract_tb(sys.exc_info()[2])
+                log.warning(''.join(traceback.format_list(tb)))
+                result += str(e)
+        else:
+            result += u'<div class="acr_wrong_view">Unsupported View Type</div>'
 
     result += u'</div>'
     return result
 
+def draw_slice(page, slicename):
+    if not page:
+        page = DBSession.query(Page).filter_by(uri='default').one()
+
+    slice = DBSession.query(Slice).filter_by(name=slicename).first()
+    return genshi.Markup(render_slice(page, slice))
+
 def draw_section(page, sect):
     if not page:
         page = DBSession.query(Page).filter_by(uri='default').one()
 
+    inherit = page.getattr('inherit')
+    if not inherit:
+        inherit = 'default'
+
     if len(page.section(sect)) == 0:
-        render_page = DBSession.query(Page).filter_by(uri='default').one()
+        render_page = DBSession.query(Page).filter_by(uri=inherit).one()
     else:
         render_page = page
 
+    section_context = render_page.section(sect)
     result = u'<div id="acr_section_%s">' % (sect)
-    for slice in render_page.section(sect):
+    if len(section_context):
+        result += u'<div class="acr_section_content">'
+    for slice in section_context:
         result += render_slice(page, slice)
     result += u'</div>'
+    if len(section_context):
+        result += u'</div>'
     return genshi.Markup(result)
 
 def user_in_group(group):
