@@ -15,6 +15,8 @@ from paste.util.multidict import MultiDict
 from attributes import Attribute
 from libacr.unicodecfp import UnicodeConfigParser
 
+acr_language = None
+
 tag_content_map = Table('acr_cms_map_content_tag', DeclarativeBase.metadata,
                         Column('tag_uid', Integer, ForeignKey('acr_cms_tag.uid')),
                         Column('content_uid', Integer, ForeignKey('acr_cms_content.uid'))
@@ -71,10 +73,12 @@ class Content(DeclarativeBase):
         return langs.keys()
 
     def get_data_instance_for_lang(self, langs=None, fallback=True):
-        from libacr.lib import language
+        global acr_language
+        if acr_language is None:
+            from libacr.lib import language as acr_language
 
         if not langs:
-            langs = language()
+            langs = acr_language()
 
         data = None
         for lang in langs:
@@ -138,23 +142,6 @@ class Content(DeclarativeBase):
                 results.append(entry)
         return results
 
-    def getattr(self, name):
-        attr = DBSession.query(Attribute).filter_by(slice=self)\
-                                         .filter_by(name=name).first()
-        if attr:
-            return attr.value
-        else:
-            return None
-
-    def setattr(self, name, value):
-        attr = DBSession.query(Attribute).filter_by(slice=self)\
-                                         .filter_by(name=name).first()
-        if attr:
-            attr.value = value
-        else:
-            DBSession.add(Attribute(name=name, value=value, slice=self))
-        
-
 class ContentData(DeclarativeBase):
     __tablename__ = 'acr_cms_content_data'
 
@@ -310,12 +297,18 @@ class Page(DeclarativeBase):
     def i18n_titles(self):
         attrs = DBSession.query(Attribute).filter_by(page=self)\
                                           .filter(Attribute.name.like('title-%'))
-        return dict([(attr.name[6:], attr.value) for attr in attrs])
+        titles = dict([(attr.name[6:], attr.value) for attr in attrs])
+        if 'en' not in titles:
+            titles['en'] = self.title
+        return titles
 
     def get_title_for_lang(self, langs=None, fallback=True):
-        from libacr.lib import language
+        global acr_language
+        if acr_language is None:
+            from libacr.lib import language as acr_language
+
         if not langs:
-            langs = language()
+            langs = acr_language()
 
         available_titles = self.i18n_titles
         for lang in langs:
@@ -361,8 +354,11 @@ class Page(DeclarativeBase):
                 return True
 
         if rule == 'supported-languages':
-            from libacr.lib import language
-            langs = [language()[0]]
+            global acr_language
+            if acr_language is None:
+                from libacr.lib import language as acr_language
+
+            langs = [acr_language()[0]]
             return self.get_title_for_lang(langs=langs, fallback=False) is not None
 
         return False
@@ -447,3 +443,19 @@ class Slice(DeclarativeBase):
 
         return text
 
+    def getattr(self, name):
+        attr = DBSession.query(Attribute).filter_by(slice=self)\
+                                         .filter_by(name=name).first()
+        if attr:
+            return attr.value
+        else:
+            return None
+
+    def setattr(self, name, value):
+        attr = DBSession.query(Attribute).filter_by(slice=self)\
+                                         .filter_by(name=name).first()
+        if attr:
+            attr.value = value
+        else:
+            DBSession.add(Attribute(name=name, value=value, slice=self))
+
