@@ -15,5 +15,7 @@ def init_acr_model(app_DBSession, app_DeclarativeBase,app_User,app_Group):
 
     from comments import Comment
     from content import Content, ContentData, Tag, Page, Slice, View
+    from assets import Asset
+    from attributes import Attribute
     from user_permission import AcrUserPermission
     return Content, ContentData, Tag, Page, Slice, View, Comment
