@@ -80,13 +80,4 @@ class PluginsManager(object):
                 sections.setdefault(action.section, []).append(action)
         return sections
 
-    def setup_models(self, DBSession, DeclarativeBase, User, Group):
-        for plugin in self.plugins.itervalues():
-            try:
-                setup_models = plugin.setup_models
-            except:
-                continue
-
-            setup_models(DBSession, DeclarativeBase, User, Group)
-
 PluginsManager = PluginsManager()
