@@ -12,6 +12,8 @@ from base import EncodedView
 from ConfigParser import ConfigParser
 from StringIO import StringIO
 
+from paste.util.multidict import MultiDict
+
 class FormRenderer(EncodedView):
     def __init__(self):
         self.name = 'form'
@@ -28,16 +30,19 @@ class FormRenderer(EncodedView):
                            ]
 
     def parse_fields(self, fields):
-        pfields = ConfigParser()
+        try:
+            pfields = ConfigParser(dict_type=MultiDict)
+        except:
+            pfields = ConfigParser()
         pfields.readfp(StringIO('[fields]\n' + fields))
         return pfields.items('fields')
 
     def to_dict(self, data):
         config = super(FormRenderer, self).to_dict(data)
-        
-        d = {'email_address' : config.get('email_address'),
-                   'subject' : config.get('subject'),
-                  'save_tag' : config.get('save_tag')}
+       
+        d = MultiDict({'email_address' : config.get('email_address'),
+                             'subject' : config.get('subject'),
+                            'save_tag' : config.get('save_tag')})
 
         fields = ''
         for field in config.items():
@@ -48,7 +53,7 @@ class FormRenderer(EncodedView):
         return d
         
     def from_dict(self, dic):
-        d = {}
+        d = MultiDict()
         d['email_address'] = dic['email_address']
         d['subject'] = dic['subject']
         d['save_tag'] = dic['save_tag']
@@ -72,7 +77,7 @@ class FormRenderer(EncodedView):
         form += '<table>'
         for item in items:
             form += '<tr class="%s_field">' % (item[0])
-            form += '<td class="form_label"> %s </td>' % (item[0].lstrip('*'))
+            form += '<td class="form_label %s"> %s </td>' % (item[0][0]=='*' and 'required' or '', item[0].lstrip('*'))
             
             item1 = item[1]
             if item1[0] == '[':
