@@ -1,14 +1,14 @@
-import ConfigParser
 from sqlalchemy.orm import join
 import libacr.helpers as h
 from tg import request, tmpl_context
-import StringIO
 
 from libacr.model.core import DBSession
 from libacr.model.content import Content, Slice, Tag
 import tw.forms as twf
 
-class SliceGroupRenderer(object):
+from base import EncodedView
+
+class SliceGroupRenderer(EncodedView):
     slice_orderers = {'content_time': lambda x : x.order_by(Content.time.desc())}
     
     def __init__(self):
@@ -29,36 +29,7 @@ class SliceGroupRenderer(object):
                                                              options=(('', "Ascending Time"),
                                                                       ('content_time', "Descending Time")))]
                                                   
-
-    def to_dict(self, data):
-        config = ConfigParser.ConfigParser({'preview':'0', 'size':'0', 'type':'div'})
-        config.readfp(StringIO.StringIO(data))
-        d = {'filter_tag' : config.get('group', 'filter_tag'),
-                'preview' : config.get('group', 'preview'),
-                   'size' : config.get('group', 'size'),
-                   'type' : config.get('group', 'type')}
-
-        try:
-            d[orderer] = config.get('group', 'orderer')
-        except:
-            pass
-        
-        return d
-
-    def from_dict(self, dic):
-        config = ConfigParser.ConfigParser()
-        config.add_section('group')
-        config.set('group', 'filter_tag', dic['filter_tag'])
-        config.set('group', 'preview', dic.get('preview', '0'))
-        config.set('group', 'size', dic.get('size', '0'))
-        config.set('group', 'type', dic.get('type', 'div'))
-        if dic.get('orderer', ''):
-            config.set('group', 'orderer', dic.get('orderer', ''))
-
-        s = StringIO.StringIO()
-        config.write(s)
-        return s.getvalue()
-        
+       
     def preview(self, page, slice, data):
         return 'Preview not Implemented'
         
@@ -68,17 +39,15 @@ class SliceGroupRenderer(object):
             args[parg] = str(page_num)
             uri = request.urlargs.current(**args)
             return uri
-        
-        config = ConfigParser.ConfigParser({'preview':'0', 'size':'0', 'type':'div'})
-        config.readfp(StringIO.StringIO(data))
-                
-        per_page = int(config.get('group', 'size'))
-        filter_tag = config.get('group', 'filter_tag')
-        preview = int(config.get('group', 'preview'))
-        type = config.get('group', 'type')
+
+        config = self.to_dict(data)                
+        per_page = int(config.get('size', '0'))
+        filter_tag = config.get('filter_tag', '')
+        preview = int(config.get('preview', '0'))
+        type = config.get('type', 'div')
         
         try:
-            orderer = config.get('group', 'orderer')
+            orderer = config.get('orderer')
             orderer = SliceGroupRenderer.slice_orderers[orderer]
         except:
             orderer = lambda x : x
