@@ -10,6 +10,8 @@ from libacr.lib import get_slices_with_tag, get_page_from_urllist
 import libacr.helpers as h
 from libacr.form_fields import AdvancedFileField
 
+acr_language = None
+
 class UserDefinedViewRendererTemplate(object):
     def __init__(self, name, code):
         self.name = name
@@ -52,8 +54,8 @@ class UserDefinedViewRendererTemplate(object):
                                                     validator=validator))
             elif field_type.lower() == 'html':
                 tw_fields.append(TinyMCE(name, label_text="%s:" % name.capitalize(), validator=MarkupConverter(),
-                                         rows=20, attrs={'style':'width:100%;height:400px;'},
-                                         mce_options=dict(theme_advanced_buttons1= """bold,italic,underline,
+                                         mce_options=dict(width='690', height='500',
+                                             theme_advanced_buttons1= """bold,italic,underline,
 strikethrough,separator,justifyleft,justifycenter,justifyright,justifyfull,separator,
 fontselect,fontsizeselect,separator,forecolor,backcolor""")))
             elif field_type.lower().startswith('select'):
@@ -99,17 +101,24 @@ fontselect,fontsizeselect,separator,forecolor,backcolor""")))
         return d
 
     def render(self, page, slice, data):
-        from libacr.lib import language
+        global acr_language
+        if acr_language is None:
+            from libacr.lib import language as acr_language
+
         data_as_dict = self.to_dict(data)
 
         try:
             t = MarkupTemplate(u'<html xmlns:py="http://genshi.edgewall.org/" py:strip="">%s</html>' % self.code)
-            t = t.generate(acr=self.acr_dict, slice_uid=slice.uid, slice=slice, lang=language()[0], **data_as_dict)
+            t = t.generate(acr=self.acr_dict, slice_uid=slice.uid, slice=slice, lang=acr_language()[0], **data_as_dict)
             return t.render('xhtml').decode('utf-8')
         except Exception, e:
             return str(e)
 
     def preview(self, page, slice, data):
+        global acr_language
+        if acr_language is None:
+            from libacr.lib import language as acr_language
+
         preview_template_name = '%s_preview' % self.name
         preview = DBSession.query(View).filter_by(name=preview_template_name).first()
 
@@ -119,7 +128,7 @@ fontselect,fontsizeselect,separator,forecolor,backcolor""")))
         data_as_dict = self.to_dict(data)
         try:
             t = MarkupTemplate(u'<html xmlns:py="http://genshi.edgewall.org/" py:strip="">%s</html>' % preview.code)
-            t = t.generate(acr=self.acr_dict, slice_uid=slice.uid, **data_as_dict)
+            t = t.generate(acr=self.acr_dict, slice_uid=slice.uid, slice=slice, lang=acr_language()[0], **data_as_dict)
             return t.render('xhtml').decode('utf-8')
         except Exception, e:
             return str(e)
